package com.bwie.auth.service.impl;

import cn.hutool.http.server.HttpServerRequest;
import com.alibaba.fastjson.JSONObject;
import com.bwie.auth.feign.AuthFeign;
import com.bwie.auth.service.AuthService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.User;
import com.bwie.common.domain.response.JwtResponse;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

/**
 * @Author：蓬叁
 * @Package：com.bwie.auth.service.impl
 * @Project：maven-week2-exam
 * @name：AuthServiceImpl
 * @Date：2024/7/30 上午9:28
 */
@Service
public class AuthServiceImpl implements AuthService {

    @Autowired private AuthFeign authFeign;
    @Autowired private RedisTemplate redisTemplate;
    @Autowired private HttpServletRequest request;
    @Autowired private BCryptPasswordEncoder bCryptPasswordEncoder;


    @Override
    public Result<JwtResponse> login(User user) {
        if (null == user.getUserName()){
            return Result.error("账号不能为空");
        }
        if (null == user.getUserPwd()){
            return Result.error("密码不能为空");
        }
        Result<User> data = authFeign.findByUserName(user.getUserName());
        User loginMsg = data.getData();
        if (null == loginMsg){
            return Result.error("账号不存在");
        }
//        String encode = bCryptPasswordEncoder.encode(user.getUserPwd());
//        System.out.println(encode);
        if (!bCryptPasswordEncoder.matches(user.getUserPwd(),loginMsg.getUserPwd())){
            return Result.error("密码错误");
        }
        Map<String, Object> map = new HashMap<>();
        String userKey = UUID.randomUUID().toString().replaceAll("-", "");
        map.put(JwtConstants.USER_KEY,userKey);
        String token = JwtUtils.createToken(map);
        redisTemplate.opsForValue().set(
                TokenConstants.LOGIN_TOKEN_KEY+userKey,
                JSONObject.toJSONString(loginMsg),
                10,
                TimeUnit.MINUTES
        );
        JwtResponse jwtResponse = new JwtResponse();
        jwtResponse.setToken(token);
        jwtResponse.setTime("10MIN");
        return Result.success(jwtResponse,"登录成功");
    }

    @Override
    public User info() {
        String token = request.getHeader(TokenConstants.TOKEN);
        String userKey = JwtUtils.getUserKey(token);
        String o = (String) redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        return JSONObject.parseObject(o,User.class);
    }
}
