package com.bwie.home.controller;

import com.bwie.common.domain.*;
import com.bwie.common.domain.dto.HomeDTO;
import com.bwie.common.domain.vo.HomeLoanApprovalVo;
import com.bwie.common.domain.vo.HomeVo;
import com.bwie.common.result.PageResult;
import com.bwie.common.result.Result;
import com.bwie.home.service.HomeService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @Author：蓬叁
 * @Package：com.bwie.home.controller
 * @Project：maven-week2-exam
 * @name：HomeController
 * @Date：2024/7/30 上午10:45
 */
@RestController
@RequestMapping("/home")
public class HomeController {

    @Autowired private HomeService homeService;

    /**
     * 房屋列表
     * @param homeDTO
     * @return
     */
    @PostMapping("/selectHomeList")
    public Result<PageResult<HomeVo>> homeList(@RequestBody HomeDTO homeDTO){
        PageHelper.startPage(homeDTO.getPageNum(), homeDTO.getPageSize());
        List<HomeVo> list = homeService.homeList(homeDTO);
        PageInfo<HomeVo> pageInfo = new PageInfo<>(list);
        Result<PageResult<HomeVo>> result = PageResult.toResult(pageInfo.getTotal(), list);
        return result;
    }

    /**
     * 出租类型下拉框
     */
    @PostMapping("/typeSelect")
    public Result<List<Type>> typeList(){
        return Result.success(homeService.typeList());
    }

    /**
     * 签约时长下拉框
     */
    @PostMapping("/housingCycleSelect")
    public Result<List<HousingCycle>> housingCycleList(){
        return Result.success(homeService.housingCycleList());
    }

    /**
     * 查看用户是否已经租房
     */
    @PostMapping("/findByHomeLoanApprovalUserId")
    public Result<Object> findByHomeLoanApprovalUserId(@RequestBody User user){
        Result<Object> result = homeService.findByHomeLoanApprovalUserId(user.getUserId());
        return result;
    }

    /**
     * 添加住房贷款记录
     */
    @PostMapping("/addHomeLoanApprovalMsg")
    public Result<Object> addHomeLoanApprovalMsg(@RequestBody HomeLoanApproval homeLoanApproval){
        return Result.success(homeService.addHomeLoanApprovalMsg(homeLoanApproval),"审核提交成功");
    }

    /**
     * 住房贷款记录列表
     */
    @PostMapping("/selectHomeLoanApprovalList")
    public Result<List<HomeLoanApprovalVo>> selectHomeLoanApprovalList(){
        return Result.success(homeService.selectHomeLoanApprovalList());
    }

}
