package com.bwie.home.scheduled;

import com.alibaba.fastjson.JSON;
import com.bwie.common.domain.HomeLoanApproval;
import com.bwie.common.domain.Notification;
import com.bwie.common.domain.User;
import com.bwie.common.domain.vo.HomeLoanApprovalVo;
import com.bwie.common.result.Result;
import com.bwie.home.HomeApplication;
import com.bwie.home.feign.UserFeign;
import com.bwie.home.service.HomeService;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.List;
import java.util.UUID;

/**
 * @Author：蓬叁
 * @Package：com.bwie.rabbitmq.consumer
 * @Project：maven-week2-exam
 * @name：ApplyScheduled
 * @Date：2024/7/30 下午1:19
 */
@Component
public class ApplyScheduled {

    @Autowired private HomeService homeService;
    @Autowired private UserFeign userFeign;
    @Autowired private RabbitTemplate rabbitTemplate;

    @Scheduled(cron = "0/30 * * * * ?")
    public void scheduling(){
        List<HomeLoanApprovalVo> HomeLoanApprovals = homeService.findHomeApplicationMsg();
        for (HomeLoanApprovalVo homeLoanApproval : HomeLoanApprovals) {
            Result<User> date = userFeign.findByUserId(homeLoanApproval.getUserId());
            User user = date.getData();
            BigDecimal amount = BigDecimal.valueOf((user.getCreditScore() / 100) * 1000);
            if (homeLoanApproval.getLoanAmount().compareTo(amount) > 0){
                homeService.updateHomeLoanApprovalState(homeLoanApproval.getLoanApprovalId(),2);
                homeService.updateHomeState(homeLoanApproval.getHomeId());
                Notification notification = new Notification();
                notification.setUserName(user.getUserName());
                notification.setLoanApprovalDate(homeLoanApproval.getLoanApprovalDate());
                notification.setHousingCycleName(homeLoanApproval.getHousingCycleName());
                notification.setLoanApprovalDate(homeLoanApproval.getLoanApprovalDate());
                rabbitTemplate.convertAndSend("send_msg", JSON.toJSONString(notification),message -> {
                    message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
                    return message;
                });
            }else {
                homeService.updateHomeLoanApprovalState(homeLoanApproval.getLoanApprovalId(),1);
            }
        }
    }

}
